Learn R Programming

nomordR (version 0.1)

get_max_stat_heur_T: get_max_stat_heur_T

Description

An internal function that returns the approximate maximum value of the T statistic for randomized samples of an input vector of categorical variables using a heuristic rule.

Usage

get_max_stat_heur_T(seq)

Arguments

seq

A vector of categorical values

Value

Integer