Learn R Programming

nomordR (version 0.1)

get_min_stat: get_min_stat

Description

An internal function that returns the exact minimum value of a given statistic for randomized samples of an input vector of categorical variables

Usage

get_min_stat(seq, statname)

Arguments

seq

A vector of categorical values

statname

The name of the statistic

Value

Integer