powered by
An internal function that returns the approximate maximum value of the T statistic for randomized samples of an input vector of categorical variables using a heuristic rule.
get_max_stat_heur_T(seq)
A vector of categorical values
Integer